==> haskell-charset-0.3.12-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-4GOy3AbNO215Ia2dL1tioj
key:                  charset-0.3.12-4GOy3AbNO215Ia2dL1tioj
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  2ae882f60a7f2ddf072c95c073bb9308
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-4GOy3AbNO215Ia2dL1tioj
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20-BooESfmG3DbHMU6mBvbzIL

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.12-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-91ANuAs7M4S4w6qiq0xjgV
key:                  charset-0.3.12-91ANuAs7M4S4w6qiq0xjgV
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  671bbcc72acbe416fe80c21d6d3b2874
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-91ANuAs7M4S4w6qiq0xjgV
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
